import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_style_index_0_lang-B6ywKfXu.js";import{I}from"./ItemsListing-BXtc3hUZ.js";import{c as a,E as _}from"./index-DxsXRykZ.js";import{d as h,r as m,w as b,o as w,a2 as y,b as k,e as r,H as E,D as p,I as n,F as D}from"./lucide-PBDL9g_H.js";import"./Toolbar-9-YOUynV.js";import"./vuetify-D_QaYjDz.js";import"./marquee_text_sync-DaSXkQIQ.js";import"./vue-router-BTykswgC.js";import"./MediaItemThumb-BK1p2KOk.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-BEUhvHYU.js";import"./Container--1QUHYu8.js";import"./index-kQIztB-E.js";import"./ListItem-CBSubOHZ.js";import"./Button-ByZOHWco.js";import"./vue-i18n-CYwaof5n.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-DELv5odx.js";import"./PanelviewItemCompact-D3zTXMMR.js";import"./userPreferences-CeeapS2c.js";import"./qrcode-CCr-KruI.js";import"./marked-C0Rlrcoy.js";import"./color-BTziYnFN.js";import"./vueuse-w9cS6Vug.js";/* empty css            */import"./swiper-BLmWk8fI.js";const S=h({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(l){const e=l,i=m(!1),t=m(),d=async function(){t.value=await a.getPodcast(e.itemId,e.provider)};b(()=>e.itemId,o=>{o&&d()},{immediate:!0}),w(()=>{const o=a.subscribe(_.MEDIA_ITEM_UPDATED,s=>{const c=s.data;t.value?.uri==c.uri&&(i.value=!0)});y(o)});const u=async function(o){return await a.getPodcastEpisodes(e.itemId,e.provider)};return(o,s)=>(r(),k(D,null,[E(f,{item:t.value},null,8,["item"]),t.value?(r(),p(I,{key:0,itemtype:"podcastepisodes","parent-item":t.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":u,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${e.itemId}.${e.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):n("",!0),t.value?(r(),p(v,{key:1,"item-details":t.value},null,8,["item-details"])):n("",!0)],64))}});export{S as default};
